
# Slixmpp: The Slick XMPP Library
# Copyright (C) 2011  Nathanael C. Fritz
# This file is part of Slixmpp.
# See the file LICENSE for copying permission.

from slixmpp.features.feature_sasl2mechanisms.stanza.mechanisms import SASL2Mechanisms
from slixmpp.features.feature_sasl2mechanisms.stanza.auth import SASL2Auth
from slixmpp.features.feature_sasl2mechanisms.stanza.success import SASL2Success
from slixmpp.features.feature_sasl2mechanisms.stanza.failure import SASL2Failure
from slixmpp.features.feature_sasl2mechanisms.stanza.challenge import SASL2Challenge
from slixmpp.features.feature_sasl2mechanisms.stanza.response import SASL2Response
from slixmpp.features.feature_sasl2mechanisms.stanza.abort import SASL2Abort



# Slixmpp: The Slick XMPP Library
# Copyright (C) 2021 Mathieu Pasquet
# This file is part of Slixmpp.
# See the file LICENSE for copying permission.

from slixmpp.xmlstream import StanzaBase
from typing import Optional


class Starttls(RootStanza):

    """
    Jabber protocol starttls
    """
    namespace = 'jabber:client'
    name = 'starttls'




# Slixmpp: The Slick XMPP Library
# Copyright (C) 2011  Nathanael C. Fritz
# This file is part of Slixmpp.
# See the file LICENSE for copying permission.
from slixmpp.plugins.base import register_plugin

from slixmpp.features.feature_sasl2mechanisms.mechanisms import FeatureSASL2Mechanisms
from slixmpp.features.feature_sasl2mechanisms.stanza import SASL2Mechanisms
from slixmpp.features.feature_sasl2mechanisms.stanza import SASL2Auth
from slixmpp.features.feature_sasl2mechanisms.stanza import SASL2Success
from slixmpp.features.feature_sasl2mechanisms.stanza import SASL2Failure


register_plugin(FeatureSASL2Mechanisms)
